GEPA.Adapters.GenericRAG.VectorStores.Qdrant (GEPA v0.3.0)

Copy Markdown View Source

Qdrant HTTP vector-store adapter for Generic RAG.

This module intentionally uses Qdrant's HTTP API directly. The behaviour surface keeps the implementation replaceable by a dedicated client library or a larger vector subsystem later.

Summary

Types

t()

@type t() :: %GEPA.Adapters.GenericRAG.VectorStores.Qdrant{
  api_key: String.t() | nil,
  collection_name: String.t(),
  distance: String.t(),
  embedder: GEPA.Embeddings.provider() | nil,
  req_options: keyword(),
  timeout: pos_integer(),
  url: String.t(),
  vector_size: pos_integer() | nil
}

Functions

hybrid_search(store, query, k, alpha)

new(opts \\ [])

@spec new(keyword() | map()) :: t()

Build a Qdrant vector store.