GEPA.OptimizeAnything.LogContext.Context (GEPA v0.3.0)

Copy Markdown View Source

Propagatable optimize-anything evaluator log context.

Use GEPA.OptimizeAnything.get_log_context/0 inside an evaluator and pass the returned context to child processes with GEPA.OptimizeAnything.set_log_context/1 when those processes should append diagnostic log entries to the parent evaluator call.

Summary

Types

t()

@type t() :: %GEPA.OptimizeAnything.LogContext.Context{agent: pid()}