Stops after a maximum number of tracked candidate programs.
Summary
Types
@type t() :: %GEPA.StopCondition.MaxTrackedCandidates{ max_tracked_candidates: pos_integer() }
Functions
@spec new(pos_integer()) :: t()
Stops after a maximum number of tracked candidate programs.
@type t() :: %GEPA.StopCondition.MaxTrackedCandidates{ max_tracked_candidates: pos_integer() }
@spec new(pos_integer()) :: t()