Stops once the best aggregate validation score reaches a threshold.
Summary
Types
@type t() :: %GEPA.StopCondition.ScoreThreshold{threshold: number()}
Stops once the best aggregate validation score reaches a threshold.
@type t() :: %GEPA.StopCondition.ScoreThreshold{threshold: number()}