Behaviour for selecting which named candidate components should be updated.
Summary
Callbacks
@callback select(GEPA.State.t(), non_neg_integer(), map()) :: {[String.t()], GEPA.State.t()}
Behaviour for selecting which named candidate components should be updated.
@callback select(GEPA.State.t(), non_neg_integer(), map()) :: {[String.t()], GEPA.State.t()}