GEPA.Strategies.EvaluationPolicy.Full (GEPA v0.3.0)

Copy Markdown View Source

Always evaluates all validation examples.

Simple and thorough, but can be expensive for large validation sets.

Summary

Functions

Calculate average score and coverage from a scores map.

Functions

calculate_avg_and_coverage(scores)

@spec calculate_avg_and_coverage(%{optional(term()) => number()}) ::
  {float(), non_neg_integer()}

Calculate average score and coverage from a scores map.

Returns a tuple of {average, count} where average is the mean of all scores and count is the number of scores evaluated.

Examples

iex> calculate_avg_and_coverage(%{})
{0.0, 0}

iex> calculate_avg_and_coverage(%{1 => 0.8, 2 => 0.9, 3 => 0.7})
{0.8, 3}