A small, adapter-local RAG pipeline used by GEPA.Adapters.GenericRAG.
Candidate components are plain text templates. Supported placeholders:
{query}, {documents}, {context}, and {metadata}.
Summary
Functions
Deterministic fallback embedding function used when no custom embedding function is supplied.
Execute a RAG pipeline using explicit query, prompt, and config arguments.
Generate an answer from query, context, and a prompt template.
Reformulate a query with a prompt template.
Retrieve documents for a query under the provided config.
Types
Functions
Deterministic fallback embedding function used when no custom embedding function is supplied.
Execute a RAG pipeline using explicit query, prompt, and config arguments.
Generate an answer from query, context, and a prompt template.
Reformulate a query with a prompt template.
Retrieve documents for a query under the provided config.